# Generated by Django 3.0.5 on 2020-05-18 05:29

from django.db import migrations, models
import django.db.models.deletion
import interceptor.validators


class Migration(migrations.Migration):

    dependencies = [
        ('interceptor', '0009_interceptormockresponse'),
    ]

    operations = [
        migrations.AlterField(
            model_name='interceptedfile',
            name='request',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='files', to='interceptor.InterceptedRequest'),
        ),
        migrations.AlterField(
            model_name='interceptedrequest',
            name='session',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='requests', to='interceptor.InterceptorSession'),
        ),
        migrations.AlterField(
            model_name='interceptormockresponse',
            name='response_body',
            field=models.TextField(validators=[interceptor.validators.JSONFormatValidator()]),
        ),
        migrations.AlterField(
            model_name='interceptormockresponse',
            name='response_headers',
            field=models.TextField(blank=True, null=True, validators=[interceptor.validators.JSONFormatValidator(allow_null=True)]),
        ),
        migrations.AlterField(
            model_name='interceptormockresponse',
            name='session',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='mocks', to='interceptor.InterceptorSession'),
        ),
    ]
