# Generated by Django 3.0.5 on 2020-05-14 06:37

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('interceptor', '0005_auto_20200514_0617'),
    ]

    operations = [
        migrations.AddField(
            model_name='interceptedrequest',
            name='path',
            field=models.CharField(default='/', max_length=255),
        ),
        migrations.AddField(
            model_name='interceptedrequest',
            name='session',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='interceptor.InterceptorSession'),
        ),
    ]
