# Generated by Django 3.0.5 on 2020-05-14 19:25

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('interceptor', '0008_interceptorsession_session_token'),
    ]

    operations = [
        migrations.CreateModel(
            name='InterceptorMockResponse',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('method', models.CharField(choices=[('get', 'GET'), ('post', 'POST'), ('put', 'PUT'), ('patch', 'PATCH'), ('delete', 'DELETE'), ('head', 'HEAD'), ('options', 'OPTIONS'), ('trace', 'TRACE')], default='get', max_length=8)),
                ('path', models.CharField(default='/', max_length=255)),
                ('status_code', models.PositiveIntegerField()),
                ('response_headers', models.TextField(blank=True, null=True)),
                ('response_body', models.TextField()),
                ('response_description', models.TextField(max_length=255)),
                ('session', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='interceptor.InterceptorSession')),
            ],
        ),
    ]
