# Generated by Django 3.0.5 on 2020-05-14 06:17

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion
import interceptor.models


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('interceptor', '0004_interceptedfile'),
    ]

    operations = [
        migrations.AddField(
            model_name='interceptedrequest',
            name='timestamp',
            field=models.DateTimeField(auto_now_add=True, null=True),
        ),
        migrations.AlterField(
            model_name='interceptedfile',
            name='file',
            field=models.FileField(blank=True, null=True, upload_to=interceptor.models.session_upload_to),
        ),
        migrations.CreateModel(
            name='InterceptorSession',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('short_name', models.CharField(blank=True, max_length=20)),
                ('active', models.BooleanField(default=True)),
                ('user', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'unique_together': {('short_name', 'user')},
            },
        ),
    ]
