# Generated by Django 3.0.5 on 2020-05-18 08:56

from django.db import migrations, models
import django.utils.timezone


class Migration(migrations.Migration):

    dependencies = [
        ('interceptor', '0010_auto_20200518_0529'),
    ]

    operations = [
        migrations.AddField(
            model_name='interceptorsession',
            name='creation_date',
            field=models.DateTimeField(auto_now_add=True, default=django.utils.timezone.now),
            preserve_default=False,
        ),
    ]
