# Generated by Django 3.0.5 on 2020-05-14 07:34

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('interceptor', '0007_auto_20200514_0713'),
    ]

    operations = [
        migrations.AddField(
            model_name='interceptorsession',
            name='session_token',
            field=models.CharField(blank=True, max_length=24, null=True),
        ),
    ]
