# Generated by Django 3.0.5 on 2020-05-14 01:24

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('interceptor', '0002_interceptedrequest_headers'),
    ]

    operations = [
        migrations.AddField(
            model_name='interceptedrequest',
            name='content_type',
            field=models.CharField(blank=True, max_length=30, null=True),
        ),
    ]
