# Generated by Django 3.0.5 on 2020-04-16 20:31

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('interceptor', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='interceptedrequest',
            name='headers',
            field=models.TextField(blank=True, null=True),
        ),
    ]
