# Generated by Django 3.0.5 on 2020-05-14 07:13

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('interceptor', '0006_auto_20200514_0637'),
    ]

    operations = [
        migrations.AddField(
            model_name='interceptorsession',
            name='requires_authentication',
            field=models.BooleanField(default=False),
        ),
        migrations.AddField(
            model_name='interceptorsession',
            name='saves_files',
            field=models.BooleanField(default=False),
        ),
    ]
